########################################################
# Impute missing features in the data, create a stan-
# dardized/normalized version and store it in a binary
# R file for easier/faster reading by subsequent scripts.
########################################################
# (c) Andreas Spitz, spitz@informatik.uni-heidelberg.de
########################################################

library(plyr)

# names of input files
inFileData <- "data_newscit_features.txt"

# names of output files
outFileBinary <- "data_newscit_features_imputed.RData"

# read input data
cat("Reading data")
# newsOutletID feedTypeID RSSFeedURI Language StartDate CountArticle
data <- read.table(inFileData, sep=" ", header=TRUE)
cat(". Done.\n")

# compute number of rows with at least one NA value
#naCounts <- Reduce('+', lapply(data, is.na))
#rowsNA <- sum(naCounts > 0)
#rowsNonNA <- sum(naCounts == 0)
#percNA <- rowsNA / length(naCounts)

# FUNCTION: simple imputation by mean
simpleMeanImputation <- function(df) {
    dataImpSimple <- df
    colNames <- names(dataImpSimple)[2:(length(names(dataImpSimple))-1)]
    for(cn in colNames) {
        vec <- dataImpSimple[,names(dataImpSimple) == cn]
        vecMean <- mean(vec,na.rm=TRUE)
        vec[is.na(vec)] <- vecMean
        dataImpSimple[,names(dataImpSimple) == cn] <- vec
    }
    return(dataImpSimple)
}

# FUNCTION: standardize values
standardize <- function(df) {
    colNames <- names(df)[2:(length(names(df))-1)]
    for(cn in colNames) {
        vec <- df[,names(df) == cn]
        standVec <- (vec - mean(vec, na.rm=TRUE)) / sd(vec, na.rm=TRUE)
        df[,names(df) == cn] <- standVec
    }
    return(df)
}

# create boolean vectors for in / out degrees
bIN <- data$degIN > 0
bOUT <- data$degOUT > 0

# actual imputation and normalization
dataImpSimple <- simpleMeanImputation(data)
dataImpSimpleStand <- standardize(dataImpSimple)

dataImpSimple$bIN <- bIN
dataImpSimple$bOUT <- bOUT

dataImpSimpleStand$bIN <- bIN
dataImpSimpleStand$bOUT <- bOUT

save(dataImpSimple, dataImpSimpleStand, file = outFileBinary, compress = TRUE)
# Load the data in subsequent scripts with: load(binFile)


