########################################################
# Evaluate the document creation time (DCT) prediction
# in a table of mean absolute error values.
# NOTE: requires output from script r05!
########################################################
# (c) Andreas Spitz, spitz@informatik.uni-heidelberg.de
########################################################

# libraries
library(xtable)

# names of input files
inFile <- "test1000_regressionResults_plotdata_niter1_nfold10_rseed42_tempExpTRUE.txt"
#inFile <- "regressionResults_plotdata_niter1_nfold10_rseed42_tempExpTRUE.txt"


# method and type names
mnames <- c("BASE","LR","BAY","NN","RF","GB","SVM")
tnames <- c("combined", "in", "out", "in+out")

# read data
plotdata <- read.table(inFile, header=TRUE, sep=" ")

# output DF
result <- data.frame(type=character(0), BASE=numeric(0), LR=numeric(0), BAY=numeric(0), NN=numeric(0), RF=numeric(0), SVM=numeric(0))

# compute table
for (t in tnames) {
    tmp <- plotdata[plotdata$nodeType == t,]
    agg <- aggregate(tmp$absErr, by=list(tmp$method), FUN=mean)
    names(agg) <- c("method","MAE")

    tmpres <- data.frame(type=t, BASE=agg$MAE[agg$method=="BASE"], LR=agg$MAE[agg$method=="LR"], BAY=agg$MAE[agg$method=="BAY"], NN=agg$MAE[agg$method=="NN"], RF=agg$MAE[agg$method=="RF"], GB=agg$MAE[agg$method=="GB"], SVM=agg$MAE[agg$method=="SVM"])

    result <- rbind(result,tmpres)
}

print(result)
cat("\n")
print(xtable(result))


